rpl_pack.utils — rpl-pack 0.0.1 documentation

# rpl_pack.utils

Utility classes and functions mostly for internal use.

Functions

`decode_arrays` | Decode json objects into numpy arrays.
`encode_arrays` | Encode numpy arrays as json objets using NumpyEncoder.
`m3m3_scfstb` | Convert from from cubic meter (m3)/cubic meter (m3) standard cubic feet (scf)/stock tank barrel (stb).
`make_array` | Create numpy array from any native data type and/or data structure.
`scfstb_m3m3` | Convert from standard cubic feet (scf)/stock tank barrel (stb) to cubic meter (m3)/cubic meter (m3).
`timer` | Decorator to time a function.

Classes

`NumpyEncoder` | Subclass of json.JSONEncoder used for encoding numpy arrays as json objects.